#!/bin/sh

CONF_FILE=/etc/eToken.conf
SAC_RPM=SafenetAuthenticationClient-8.0.5-0.x86_64.rpm

MAJ_VER=8
MIN_VER=0
REV_VER=5
BUILD_VER=0

lang_arg=$1

print_menu ()
{
	echo
	echo
	echo " Choose Client Language:"
	echo "------------------------"
	echo "1. English.....(En)"
	echo "2. Spanish.....(Es)"
	echo "3. French......(Fr)"
	echo "4. Italian.....(It)"
	echo "5. Japanese....(Jp)"
	echo "6. Korean......(Ko)"
	echo "7. Russian.....(Ru)"
	echo "8. Chinese.....(Zh)"
	echo "9. Portoguese..(Pt)"
	echo "10. Thai.......(Th)"
	echo
	echo -n "Your choice [1-10] -->"
	return 0
}

set_lang_code ()
{
	lang=$1
	echo "Installing Language code ${lang}."
	cat ${CONF_FILE} | sed -e "s/LanguageId=[A-Z][a-z]/LanguageId=${lang}/" > /tmp/eToken.conf.new
	mv /tmp/eToken.conf.new ${CONF_FILE}
	echo "Done!"
	return 0
}

set_lang ()
{
	lang=En
	if [ $1 == "1" ] ; then
		lang=En
	elif [ $1 == "2" ] ; then
		lang=Es
	elif [ $1 == "3" ] ; then
		lang=Fr
	elif [ $1 == "4" ] ; then
		lang=It
	elif [ $1 == "5" ] ; then
		lang=Jp
	elif [ $1 == "6" ] ; then
		lang=Ko
	elif [ $1 == "7" ] ; then
		lang=Ru
	elif [ $1 == "8" ] ; then
		lang=Zh
	elif [ $1 == "9" ] ; then
		lang=Pt
	elif [ $1 == "10" ] ; then
		lang=Th
	else
		echo "Error: only 1-10"
		return 1
	fi
	set_lang_code ${lang}
	return 0
}

check_root ()
{
if [ ! $UID == "0" ] ; then
	echo "Please run this script as root!"
	exit 1
fi
return 0
}

compare_ver(){
FVER=$1
FINST_VER=$2
if [ $FVER -lt $FINST_VER ]
then
        echo "Latest version of SafeNet Authentication Client already installed!"
	echo "Installer will exit now..."
        exit 1
else
        if [ ! $FVER -eq $FINST_VER ] ; then
                echo "Older version of SAC/PKI client detected."
		echo "Continuing installation will remove existing SAC/PKI client."
		echo "Do you want to continue with the installation (y/n) :"

		read yesno
		case "$yesno" in
		yes|y|Y|YES|Yes)
			echo "Removing existing SAC/PKI client."
	                if [ "$INST_PKG_NAME_PKI" = "pkiclient" ]
			then
				 rpm -e pkiclient
			else
				rpm -e SafenetAuthenticationClient
			fi

        	        if ! rpm -ih --nomd5 --nodeps ${SAC_RPM} ; then
                	        echo "Error installing rpm."
                        	exit 1
                	fi
                	exit 0
		;;
		*)
			echo "Exiting installation....."
			exit
		esac	
        fi
fi
}

check_root

set `rpm -q pkiclient`
INSTALLED_PKG_PKI=$1
set `rpm -q SafenetAuthenticationClient`
INSTALLED_PKG_SAC=$1

set `cut -d'-' -f1 <<< "$INSTALLED_PKG_PKI"`
INST_PKG_NAME_PKI=$1
set `cut -d'-' -f1 <<< "$INSTALLED_PKG_SAC"`
INST_PKG_NAME_SAC=$1

if [ "$INST_PKG_NAME_PKI" = "pkiclient"  -a "$INST_PKG_NAME_SAC" = "SafenetAu" ]
then
	echo "Both PKI client and SAC are installed. It is highly recommended you uninstall the older version of the authentication client."
	echo "Exiting Installation script."
	exit
fi

if [ "$INST_PKG_NAME_PKI" = "pkiclient" ]
then
	set `cut -c 11 <<< "$INSTALLED_PKG_PKI"`
	INST_MAJ_VER=$1
	set `cut -c 13 <<< "$INSTALLED_PKG_PKI"`
	INST_MIN_VER=$1
	set `cut -c 15 <<< "$INSTALLED_PKG_PKI"`
	INST_REV_VER=$1
	set `cut -c 17 <<< "$INSTALLED_PKG_PKI"`
	INST_BUILD_VER=$1
	compare_ver $MAJ_VER $INST_MAJ_VER
	compare_ver $MIN_VER $INST_MIN_VER
	compare_ver $REV_VER $INST_REV_VER
	compare_ver $BUILD_VER $INST_BUILD_VER
	echo "Same version already installed"
	echo "Exiting Installation script..."
	exit
elif [ "$INST_PKG_NAME_SAC" = "SafenetAuthenticationClient" ]
then
        set `cut -c 29 <<< "$INSTALLED_PKG_SAC"`
        INST_MAJ_VER=$1
        set `cut -c 31 <<< "$INSTALLED_PKG_SAC"`
        INST_MIN_VER=$1
        set `cut -c 33 <<< "$INSTALLED_PKG_SAC"`
        INST_REV_VER=$1
        set `cut -c 35 <<< "$INSTALLED_PKG_SAC"`
        INST_BUILD_VER=$1
        compare_ver $MAJ_VER $INST_MAJ_VER
        compare_ver $MIN_VER $INST_MIN_VER
        compare_ver $REV_VER $INST_REV_VER
        compare_ver $BUILD_VER $INST_BUILD_VER
        echo "Same version already installed"
        echo "Exiting Installation script..."
        exit
else
        if ! rpm -ih --nomd5 --nodeps ${SAC_RPM} ; then
		echo "Error installing rpm."
		exit 1
	fi
fi

#if ! rpm -q SafenetAuthenticationClient-8.0.5-0 > /dev/null ; then
#	if ! rpm -ih --nomd5 ${ETOKEN_RPM} ; then
#		echo "Error installing rpm."
#		exit 1
#	fi
#fi
#if [ -z $1 ] ; then
if [ -z $lang_arg ] ; then
	print_menu
	read choice
	set_lang ${choice}
else
	if [ $lang_arg == "En" -o $lang_arg == "Es" -o $lang_arg == "Fr" -o $lang_arg == "It" -o $lang_arg == "Jp" -o $lang_arg == "Ko" -o $lang_arg == "Ru" -o $lang_arg == "Zh" -o $lang_arg == "Pt" -o $lang_arg == "Th" ] ; then
		set_lang_code $lang_arg
	else
		echo "Unknown language id: $lang_arg."
		exit 1
	fi
fi




	
	
